# Project security

I take security very seriously.

## Reporting

Please report all vulnerability at the [private vulnerability reporting](https://github.com/Josiah-Jarvis/MCModUpdater/security/advisories/new)

## Versions

Only the latest stable version will receive security updates.
